# WaBach

This is an implementation of the Weyl and the Bach tensor on top of the [GraviPy](https://github.com/wojciechczaja/GraviPy#gravipy).

## Installation

For the installation, just type
```sh
$    pip install WaBach
```
The package heavily depends on the [GraviPy](https://github.com/wojciechczaja/GraviPy#gravipy) package and inherently on the SymPy (symbolic python).